@@ -33,14 +33,16 @@
 #' generic functions.
 #'
 #' @section Concept:
-#' Top-level entry points are either a character vector, which is used to
-#' subset a `concept` object or an entire [concept
+#' Top-level entry points are either a character vector of concept names or an
+#' integer vector of concept IDs (matched against `omopid` fields), which are
+#' used to subset a `concept` object or an entire [concept
 #' dictionary][load_dictionary()], or a `concept` object. When passing a
-#' character vector as first argument, the most important further arguments at
-#' that level control from where the dictionary is taken (`dict_name` or
-#' `dict_dirs`). At `concept` level, the most important additional arguments
-#' control the result structure: data merging can be disabled using
-#' `merge_data` and data aggregation is governed by the `aggregate` argument.
+#' character/integer vector as first argument, the most important further
+#' arguments at that level control from where the dictionary is taken
+#' (`dict_name` or `dict_dirs`). At `concept` level, the most important
+#' additional arguments control the result structure: data merging can be
+#' disabled using `merge_data` and data aggregation is governed by the
+#' `aggregate` argument.
 #'
 #' Data aggregation is important for merging several concepts into a
 #' wide-format table, as this requires data to be unique per observation (i.e.
@@ -190,6 +192,60 @@ load_concepts.character <- function(x, src = NULL, concepts = NULL, ...,
   }
 }
 
+#' @rdname load_concepts
+#' @export
+load_concepts.integer <- function(x, src = NULL, concepts = NULL, ...,
+                                  dict_name = "concept-dict",
+                                  dict_dirs = NULL) {
+
+  assert_that(no_na(x))
+
+  if (is.null(concepts)) {
+
+    assert_that(not_null(src))
+
+    concepts <- load_dictionary(src, name = dict_name, cfg_dirs = dict_dirs)
+
+  } else if (not_null(src)) {
+
+    concepts <- subset_src(concepts, src)
+  }
+
+  mapping <- set_names(
+    int_ply(concepts, `[[`, "omopid"),
+    chr_ply(concepts, `[[`, "name")
+  )
+
+  hits <- match(x, mapping)
+
+  if (any(is.na(hits))) {
+
+    warn_ricu("
+      The following {qty(sum(is.na(hits)))} concept{?s} could not be matched:
+      {concat(x[is.na(hits)])}",
+      "omop_miss_id"
+    )
+
+    hits <- hits[!is.na(hits)]
+  }
+
+  res <- load_concepts(concepts[hits], src = NULL, ...)
+
+  res <- rename_cols(res, paste0("omop_", mapping[data_vars(res)]),
+                     data_vars(res), by_ref = TRUE)
+
+  res
+}
+
+#' @rdname load_concepts
+#' @export
+load_concepts.numeric <- function(x, ...) {
+
+  assert_that(all_fun(x, is_intish))
+
+  load_concepts(as.integer(x), ...)
+}
+
 #' @param aggregate Controls how data within concepts is aggregated
 #' @param merge_data Logical flag, specifying whether to merge concepts into
 #' wide format or return a list, each entry corresponding to a concept
